%
%% DISPLAY_RESULTS
% Show postion, velocity, force, and acceleration limits and generate
% setpoint plot
%
%
%%
function [f, x_t, x_v, x_a, x_min, g_max_f] = d_STI_40_display_results(P_MAX,VEL_MAX,F_MAX,G_MAX,K_ENC,Mp,Ml,Mt)
%
% Limit the maximum acceleration of stage (m/s^2)
if (G_MAX > 1.0 )
    G_MAX = 1.0; % max limit is 1 g for a 1.5 kg load
end
% Conver acceleration limit (m/s^2)
ACC_MAX= G_MAX * 9.81;
% Convert velocity limit (mm/s)
VEL_MAX_MM = VEL_MAX * 1000;
% Convert position limit (mm/s)
P_MAX_MM = P_MAX * 1000;
% Calculate maximum amplitude of position command that the Shake Table II
% can track at various frequencies.
[f,x_t,x_v,x_a,x_min] = d_setpoint_limit(P_MAX_MM, VEL_MAX_MM, ACC_MAX);
% Calculate the maximum possible acceleration of the load given the limits.
[g_max_f] = d_load_acceleration(f,x_min);
% 
%% Display
disp(' ')
disp('ENCODER CALIBRATION')
disp( [ '   K_ENC = ' num2str( K_ENC,4 ) ' m/counts' ] )
disp(' ')
disp('LOAD')
disp( [ '   Mass of top stage and bearing parts = ' num2str( Mp,3 ) ' kg' ] )
disp( [ '   Load added = ' num2str( Ml,3 ) ' kg' ] )
disp( [ '   Total load = ' num2str( Mt,3 ) ' kg' ] )
disp( [ '   NOTE: Shake Table I-40 specified for moving 1.5 kg load at 1 g' ] )
disp(' ')
disp('LIMITS')
disp( [ '   Position limit of table = +/- ' num2str( P_MAX_MM,4 ) ' mm' ] )
disp( [ '   Max velocity deliverable by motor = ' num2str( VEL_MAX_MM,4 ) ' mm/s' ] )
disp( [ '   Max force deliverable by motor = ' num2str( F_MAX,6 ) ' N' ] )
disp( [ '   Max load acceleration = ' num2str( G_MAX,4 ) ' g' ] )    
disp(' ')   
% 
%% PLOT
% Prompt user if performance limitations plot should be generated.
% 
input_str = input('Do you want to view the setpoint limitations plot? (y/[n]) ','s');
%
if strcmpi(input_str,'y')
    % Plot 1: Setpoint limitations.
    subplot(2,1,1);    
    plot(f',x_t,'b-.',f',x_v,'r',f',x_a,'g',f',x_min,'k.');
    axis([0.1 10 0 50]);
    ylabel('Amplitude (mm)');    
    text (1,35,'ALL COMMANDS SHOULD BE UNDER THE BLACK LINE' );
    legend('Mechanical Limit','Velocity Limit','Acceleration Limit','Combined Limit');
    %
    % Plot 2: Acceleration at combined setpoint limitation.
    subplot(2,1,2);
    plot(f',g_max_f,'b-');
    axis([0.1 10 0 1.25*max(g_max_f)]);
    grid;
    xlabel('Frequency (Hz)');
    ylabel('Accelerations (g)');
    title('Load Acceleration when Moving Stage at the "Combined Limit" Amplitude');
end