% ************************************************************************
% D_STI_40_LIMITS
%
% Computes the maximum velocity and force deliverable by the STI_40 series
% motor and the maximum acceleration given the total load mass.
%
% Input parameters:
%   Km          Back-emf constant (V/(rad/s))
%   Kt          Current-torque constant (N.m/A)
%   Pb          Ball-screw pitch (m/rev)
%   Mt          Total load mass (kg)
%   Jeq         Equivalent Load Moment of inertia on rotor (kg.m^2)
%   VMAX_AMP    Maximum output voltage of amplifier (V)
%   IMAX_AMP    Maximum output continuous current of amplifier (A)
%
% Output parameters:
%   VEL_MAX     Maximum linear velocity of stage (m/s)
%   F_MAX       Maximum linear force of stage (m/s^2)
%   ACC_MAX     Maximum linear acceleration of stage given load mass (m/s^2)
%   G_MAX       Maximum linear acceleration of stage given load mass (g)
%
% Copyright (C) 2007 Quanser Consulting Inc.
% Quanser Consulting Inc.
% ************************************************************************
%
function [ VEL_MAX, F_MAX, ACC_MAX, G_MAX  ] = d_STI_40_limits( Kt, Km, Pb, Mt, Jeq, IMAX_AMP, VMAX_AMP )
%
% Maximum angular velocity of motor (rad/s)
W_MAX = VMAX_AMP / Km; % 41.8 rad/s: less than rated max motor speed of 418 rad/s
% Maximum Linear Velocity (m/s)
VEL_MAX = W_MAX * Pb / (2 * pi);
% Maximum force (N)
F_MAX = Kt * IMAX_AMP / Pb;
% Maximum Acceleration (m/s^2)
ACC_MAX = F_MAX / Mt;
% Maximum Acceleration (g)
G_MAX = ACC_MAX / 9.81;

% Maximum Acceleration (m/s^2)
% ACC_MAX = Kt * Pb * IMAX_AMP  / Jeq;
% Maximum Acceleration (g)
% G_MAX = ACC_MAX / 9.81;
% Maximum force (N)
% F_MAX = Mt * ACC_MAX;
