%
%% SETUP_STI_40
%
% Sets the Shake Table I-40 system parameters, designs a
% Proportional-Derivative position controller, and loads four sample
% earthquakes.
% 
% Copyright (C) 2012 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
clear all
%
%% USER INPUT
% Added load mass (kg)
Ml = 0;
% Enable/Diable table watchdog: set to 0 to diable or 1 to enable
TBL_WATCHDOG = 1;
% Amplifier type
AMP_TYPE = 'VoltPAQ';
% Amplifier gain (V/V)
% Important: Make the gain switch on the amplifier is set to the same.
K_AMP = 3;
% 
%% CONTROL PARAMETERS
% PV Controller Design Specifications
% Spec #1: maximum percent overshoot
PO = 5.0;
% Spec #2: time of first peak
tp = 0.04;
%
%% HIL WATCHDOG
% Default sample interval of controller (s)
Ts = 2e-3;
% Stop controller if controller below the sample interval specified (s)
hil_timeout = 20*Ts;
%
%% LOAD TABLE PARAMETERS
% Calculate conversion factors
[ K_R2D, K_D2R, K_IN2M, K_M2IN, K_RDPS2RPM, K_RPM2RDPS, K_OZ2N, K_N2OZ, K_LBS2N, K_N2LBS, K_G2MS, K_MS2G ] = calc_conversion_constants ();
% Shake Table I-40 Parameters
[ Rm, Kt, Km, Pb, Mp, Ml_max, Jeq, Tc_max, cal_tol, IMAX_AMP, VMAX_AMP, P_MAX, K_E_T, K_CURR ] = config_STI_40( Ml );
% Total mass = mass of pre-load + load (kg)
Mt = Mp + Ml;
% Design and load position control PD gains.
% **Note: For control calculation, use pre-load mass and ignore load.
[Kf, K] = d_STI_40_pd(Kt, Km, Mp, Pb, Rm, tp, PO);
% Shake Table I-40-S23 Limits
[ VEL_MAX, F_MAX, ACC_MAX, G_MAX  ] = d_STI_40_limits( Kt, Km, Pb, Mt, Jeq, IMAX_AMP, VMAX_AMP );
% Load filter parameters
[wf, zf, wa, za, wd, zd] = d_STI_40_filter_specs();
% DAQ Digital-to-Analog Maximum Voltage (V)
VMAX_DAC = 10;
%
%% DISPLAY RESULTS
% Bandwidth plots
[f, x_t, x_v, x_a, x_min, g_max_f] = d_STI_40_display_results(P_MAX,VEL_MAX,F_MAX,G_MAX,K_E_T,Mp,Ml,Mt);
%
disp( ' ' );
disp( 'Shake Table PV control gains: ' );
disp( [ 'Kp = ' num2str( K(1) ) ' V/m' ] );
disp( [ 'Kv = ' num2str( K(2) ) ' V/(m/s)' ] );
