%
%% SETUP_AMD1
%
% Sets the AMD-1 system parameters, designs a Proportional-Velocity (PV) 
% position controller for the cart and a state-feedback gain (K) for the
% active damping.
% 
% Copyright (C) 2012 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
%% USER-DEFINED AMD PARAMETERS
% Amplifier type
AMP_TYPE_AMD = 'VoltPAQ';
% Amplifier gain (V/V)
K_AMP_AMD = 3;
% Type of motorized cart: set to 'IP01', 'IP02'
CART_TYPE = 'IP02';
% Type of Cart Load: set to 'NO_WEIGHT', 'ONE_WEIGHT', 'TWO_WEIGHT'
CART_LOAD_TYPE = 'TWO_WEIGHT';
% PV Controller Design Specifications
PO_c = 10;         % spec #1: maximum of 10% overshoot
tp_c = 0.15;     % spec #2: 150 ms time of first peak
% desired state-feedback controller poles
P = [ -6 + 15i, -6 - 15i, -8, -16 ];
% desired full-order observer poles
OP = [ -20, -25, -30, -35 ];
% Turn on or off the safety watchdog on the cart position: set it to 1 , or 0 
% XC_LIM_ENABLE = 1;       % safety watchdog turned ON
XC_LIM_ENABLE = 0;      % safety watchdog turned OFF
% Safety Limits on the cart displacement (m)
XC_MAX = 0.1;            % cart displacement maximum safety position
XC_MIN = - XC_MAX;        % cart displacement minimum safety position
% 
%% AMD
% Load AMD parameters and control gains.
[wcf, zetaf, wcf_a, zetaf_a, Kp_c, Kv_c, Kamd, Gamd, A, B, C, D, K_E_C, K_P_C, K_ACC, VMAX_AMD] = d_amd1_obs_cntrl(CART_TYPE, CART_LOAD_TYPE, AMP_TYPE_AMD, PO_c, tp_c, P, OP);
%
disp( ' ' );
disp( 'AMD-1 Cart PV control gains: ' );
disp( [ 'Kp = ' num2str( Kp_c ) ' V/m' ] );
disp( [ 'Kv = ' num2str( Kv_c ) ' V.s/m' ] );
% Display observer and state-feedback gains
disp( ' ' );
disp( 'AMD-1 state-feedback gain vector: ' );
Kamd